@@ -2,6 +2,8 @@ import sys
 import os
 from pathlib import Path
 import shutil
+import subprocess
+
 
 import requests
 import typer
@@ -64,14 +66,18 @@ def create(project_name: str = typer.Argument("magic-server"), replace: bool = F
 
 @app.command()
 def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
-    print("exec", sys.executable)
+    out = subprocess.run(["which", "python"], stdout=subprocess.PIPE)
+
+    # intr = os.system("which python")
+    print("INTR", out.stdout.decode("utf-8").strip())
+
+    # print("exec", sys.executable)
     """
     prefix = getattr(sys, "prefix", "")
     base_prefix = getattr(sys, "base_prefix", "")
 
     print("prefix", prefix, "\nbase_prefix", base_prefix)
     print("which python")
-    os.system("which python")
     """
     main_filename = "main.py"
     if not Path(main_filename).exists():
